# `egg-smol` Python wrapper

[![Documentation Status](https://readthedocs.org/projects/egg-smol-python/badge/?version=latest)](https://egg-smol-python.readthedocs.io/en/latest/?badge=latest) [![Test](https://github.com/metadsl/egg-smol-python/actions/workflows/CI.yml/badge.svg?branch=main)](https://github.com/metadsl/egg-smol-python/actions/workflows/CI.yml) [![PyPi Package](https://img.shields.io/pypi/v/egg-smol.svg)](https://pypi.org/project/egg-smol/) [![License](https://img.shields.io/pypi/l/egg-smol.svg)](https://pypi.org/project/egg-smol/) [![Python Versions](https://img.shields.io/pypi/pyversions/egg-smol.svg)](https://pypi.org/project/egg-smol/) [![pre-commit](https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit)](https://github.com/pre-commit/pre-commit)

`egg-smol` is a Python package that provides bindings to the Rust library [`egg-smol`](https://github.com/mwillsey/egg-smol/),
allowing you to use e-graphs in Python for optimization, symbolic computation, and analysis.

Please see the [documentation](https://egg-smol-python.readthedocs.io/en/latest/) for more information.
